@@ -15,7 +15,6 @@ import contextlib
 import copy
 import fixtures
 import pickle
-import sys
 from unittest import mock
 import warnings
 
@@ -44,7 +43,7 @@ enginefacade.transaction_context_provider(oslo_context.RequestContext)
 
 class SingletonOnName(mock.MagicMock):
     def __init__(self, the_name, **kw):
-        super(SingletonOnName, self).__init__(
+        super().__init__(
             __eq__=lambda self, other: other._assert_name == self._assert_name,
             _assert_name=the_name,
             **kw
@@ -56,14 +55,14 @@ class SingletonOnName(mock.MagicMock):
 
 class SingletonConnection(SingletonOnName):
     def __init__(self, **kw):
-        super(SingletonConnection, self).__init__(
+        super().__init__(
             "connection", **kw)
         self.info = {}
 
 
 class SingletonEngine(SingletonOnName):
     def __init__(self, connection, **kw):
-        super(SingletonEngine, self).__init__(
+        super().__init__(
             "engine",
             connect=mock.Mock(return_value=connection),
             pool=mock.Mock(),
@@ -73,7 +72,7 @@ class SingletonEngine(SingletonOnName):
         )
 
 
-class NonDecoratedContext(object):
+class NonDecoratedContext:
     """a Context object that's not run through transaction_context_provider."""
 
 
@@ -112,7 +111,7 @@ class MockFacadeTest(test_base.BaseTestCase):
     slave_uri = None
 
     def setUp(self):
-        super(MockFacadeTest, self).setUp()
+        super().setUp()
 
         writer_conn = SingletonConnection()
         writer_engine = SingletonEngine(writer_conn)
@@ -255,12 +254,16 @@ class MockFacadeTest(test_base.BaseTestCase):
         engine_factory = mock.Mock(side_effect=create_engine)
         engine_factory(
             sql_connection=self.engine_uri,
-            **dict((k, mock.ANY) for k in self.factory._engine_cfg.keys())
+            **{
+                k: mock.ANY for k in self.factory._engine_cfg.keys()
+            },
         )
         if self.slave_uri:
             engine_factory(
                 sql_connection=self.slave_uri,
-                **dict((k, mock.ANY) for k in self.factory._engine_cfg.keys())
+                **{
+                    k: mock.ANY for k in self.factory._engine_cfg.keys()
+                },
             )
 
         yield AssertDataSource(
@@ -357,11 +360,11 @@ class MockFacadeTest(test_base.BaseTestCase):
         maker_factories = mock.Mock(side_effect=get_maker)
 
         maker_factories(
-            autocommit=False, engine=engines.writer,
+            engine=engines.writer,
             expire_on_commit=False)
         if self.slave_uri:
             maker_factories(
-                autocommit=False, engine=engines.async_reader,
+                engine=engines.async_reader,
                 expire_on_commit=False)
 
         yield makers
@@ -781,26 +784,6 @@ class MockFacadeTest(test_base.BaseTestCase):
                 with self._assert_writer_session(makers) as session:
                     session.execute("test2")
 
-    def test_deprecated_async_reader_name(self):
-        if sys.version_info >= (3, 7):
-            self.skipTest("Test only runs on Python < 3.7")
-
-        context = oslo_context.RequestContext()
-
-        old = getattr(enginefacade.reader, "async")
-
-        @old
-        def go1(context):
-            context.session.execute("test1")
-
-        go1(context)
-
-        with self._assert_engines() as engines:
-            with self._assert_makers(engines) as makers:
-                with self._assert_async_reader_session(
-                        makers, assert_calls=False) as session:
-                    session.execute("test1")
-
     def test_async_reader_then_reader_ok(self):
         context = oslo_context.RequestContext()
 
@@ -1172,7 +1155,7 @@ class MockFacadeTest(test_base.BaseTestCase):
     def test_context_found_for_class_method(self):
         context = oslo_context.RequestContext()
 
-        class Spam(object):
+        class Spam:
             @classmethod
             @enginefacade.reader
             def go(cls, context):
@@ -1379,6 +1362,19 @@ class PatchFactoryTest(test_base.BaseTestCase):
         self.assertTrue(engine_args['sqlite_fk'])
         self.assertEqual("FOOBAR", engine_args["mysql_sql_mode"])
         self.assertEqual(38, engine_args["max_overflow"])
+        self.assertNotIn("mysql_wsrep_sync_wait", engine_args)
+
+    def test_new_manager_from_options(self):
+        """test enginefacade's defaults given a default structure from opts"""
+
+        factory = enginefacade._TransactionFactory()
+        cfg.CONF.register_opts(options.database_opts, 'database')
+        factory.configure(**dict(cfg.CONF.database.items()))
+        engine_args = factory._engine_args_for_conf(None)
+
+        self.assertEqual(None, engine_args["mysql_wsrep_sync_wait"])
+        self.assertEqual(True, engine_args["sqlite_synchronous"])
+        self.assertEqual("TRADITIONAL", engine_args["mysql_sql_mode"])
 
 
 class SynchronousReaderWSlaveMockFacadeTest(MockFacadeTest):
@@ -1467,7 +1463,7 @@ class ThreadingTest(db_test_base._DbTestCase):
 
         test_instance = self
 
-        class MockThreadingLocal(object):
+        class MockThreadingLocal:
             def __init__(self):
                 self.__dict__['state'] = collections.defaultdict(dict)
 
@@ -1657,7 +1653,7 @@ class LiveFacadeTest(db_test_base._DbTestCase):
     """
 
     def setUp(self):
-        super(LiveFacadeTest, self).setUp()
+        super().setUp()
 
         metadata = MetaData()
         user_table = Table(
@@ -1673,7 +1669,7 @@ class LiveFacadeTest(db_test_base._DbTestCase):
 
         reg = registry()
 
-        class User(object):
+        class User:
             def __init__(self, name):
                 self.name = name
 
