@@ -18,19 +18,16 @@ from urllib import parse
 
 import fixtures
 import sqlalchemy
-from sqlalchemy.dialects import mysql
 from sqlalchemy import Boolean, Index, Integer, DateTime, String
-from sqlalchemy import CheckConstraint
 from sqlalchemy import MetaData, Table, Column
 from sqlalchemy import ForeignKey, ForeignKeyConstraint
 from sqlalchemy.dialects.postgresql import psycopg2
-from sqlalchemy.engine import url as sa_url
 from sqlalchemy.exc import OperationalError
 from sqlalchemy.ext.hybrid import hybrid_property
+from sqlalchemy.orm import column_property
 from sqlalchemy.orm import declarative_base
-from sqlalchemy.orm import mapper
+from sqlalchemy.orm import registry
 from sqlalchemy.orm import Session
-from sqlalchemy import PrimaryKeyConstraint
 from sqlalchemy import sql
 from sqlalchemy.sql.expression import cast
 from sqlalchemy.sql import select
@@ -76,7 +73,7 @@ class FakeTable(Base):
     updated_at = Column(DateTime, nullable=True)
     enabled = Column(Boolean, default=True)
 
-    _expr_to_appease_mox = project_id + snapshot_id
+    _some_hybrid = column_property(project_id + snapshot_id)
 
     @hybrid_property
     def some_hybrid(self):
@@ -84,7 +81,7 @@ class FakeTable(Base):
 
     @some_hybrid.expression
     def some_hybrid(cls):
-        return cls._expr_to_appease_mox
+        return cls._some_hybrid
 
     def foo(self):
         pass
@@ -93,7 +90,7 @@ class FakeTable(Base):
 class FakeTableJoinedInh(FakeTable):
     __tablename__ = 'fake_table_inh'
 
-    id = Column(String(50), ForeignKey('fake_table.user_id'))
+    id = Column(String(50), ForeignKey('fake_table.user_id'), primary_key=True)
 
 
 class FakeTableSingleInh(FakeTable):
@@ -122,7 +119,7 @@ class FakeTableWithIndexes(Base):
     )
 
 
-class FakeTableClassicalyMapped(object):
+class FakeTableClassicalyMapped:
     pass
 
 
@@ -133,10 +130,11 @@ fake_table = Table(
     Column('key', String(50))
 )
 
-mapper(FakeTableClassicalyMapped, fake_table)
+reg = registry()
+reg.map_imperatively(FakeTableClassicalyMapped, fake_table)
 
 
-class FakeModel(object):
+class FakeModel:
     def __init__(self, values):
         self.values = values
 
@@ -159,7 +157,7 @@ class FakeModel(object):
 
 class TestPaginateQuery(test_base.BaseTestCase):
     def setUp(self):
-        super(TestPaginateQuery, self).setUp()
+        super().setUp()
 
         self.query = mock.Mock()
         self.mock_asc = self.useFixture(
@@ -313,10 +311,16 @@ class TestPaginateQuery(test_base.BaseTestCase):
             'another_crit',
         ]
 
-        with mock.patch.object(self.model.user_id, 'isnot') as mock_isnot, \
-                mock.patch.object(self.model.user_id, 'is_') as mock_is_a, \
-                mock.patch.object(self.model.project_id, 'is_') as mock_is_b:
-            mock_isnot.return_value = 'asc_null_1'
+        with mock.patch.object(
+            self.model.user_id.comparator.expression, 'is_not'
+        ) as mock_is_not, \
+                mock.patch.object(
+                    self.model.user_id.comparator.expression, 'is_'
+                ) as mock_is_a, \
+                mock.patch.object(
+                    self.model.project_id.comparator.expression, 'is_'
+                ) as mock_is_b:
+            mock_is_not.return_value = 'asc_null_1'
             mock_is_a.side_effect = [
                 'desc_null_filter_1',
                 'desc_null_filter_2',
@@ -332,7 +336,7 @@ class TestPaginateQuery(test_base.BaseTestCase):
                                  sort_dirs=[
                                      'asc-nullslast', 'desc-nullsfirst'])
 
-            mock_isnot.assert_called_once_with(None)
+            mock_is_not.assert_called_once_with(None)
             mock_is_a.assert_has_calls([
                 mock.call(None),
                 mock.call(None),
@@ -386,11 +390,17 @@ class TestPaginateQuery(test_base.BaseTestCase):
         mock_and.return_value = 'some_crit'
         mock_or.side_effect = ['or_1', 'some_f']
 
-        with mock.patch.object(self.model.user_id, 'isnot') as mock_isnot, \
-                mock.patch.object(self.model.updated_at, 'is_') as mock_is_a, \
-                mock.patch.object(self.model.user_id, 'is_') as mock_is_b:
+        with mock.patch.object(
+            self.model.user_id.comparator.expression, 'is_not'
+        ) as mock_is_not, \
+                mock.patch.object(
+                    self.model.updated_at.comparator.expression, 'is_'
+                ) as mock_is_a, \
+                mock.patch.object(
+                    self.model.user_id.comparator.expression, 'is_'
+                ) as mock_is_b:
 
-            mock_isnot.return_value = 'asc_null_1'
+            mock_is_not.return_value = 'asc_null_1'
             mock_is_a.return_value = 'desc_null_1'
             mock_is_b.side_effect = ['asc_null_filter_1', 'asc_null_filter_2']
 
@@ -399,7 +409,7 @@ class TestPaginateQuery(test_base.BaseTestCase):
                                  marker=self.marker,
                                  sort_dirs=[
                                      'asc-nullslast', 'desc-nullsfirst'])
-            mock_isnot.assert_called_once_with(None)
+            mock_is_not.assert_called_once_with(None)
             mock_is_a.assert_called_once_with(None)
             mock_is_b.assert_has_calls([mock.call(None), mock.call(None)])
 
@@ -447,12 +457,20 @@ class TestPaginateQuery(test_base.BaseTestCase):
         ]
         self.query.filter.return_value = self.query
 
-        with mock.patch.object(self.model.user_id, 'isnot') as mock_isnot, \
-                mock.patch.object(self.model.updated_at, 'is_') as mock_is_a, \
-                mock.patch.object(self.model.user_id, 'is_') as mock_is_b, \
-                mock.patch.object(self.model.project_id, 'is_') as mock_is_c:
+        with mock.patch.object(
+            self.model.user_id.comparator.expression, 'is_not'
+        ) as mock_is_not, \
+                mock.patch.object(
+                    self.model.updated_at.comparator.expression, 'is_'
+                ) as mock_is_a, \
+                mock.patch.object(
+                    self.model.user_id.comparator.expression, 'is_'
+                ) as mock_is_b, \
+                mock.patch.object(
+                    self.model.project_id.comparator.expression, 'is_'
+                ) as mock_is_c:
 
-            mock_isnot.return_value = 'asc_null_1'
+            mock_is_not.return_value = 'asc_null_1'
             mock_is_a.return_value = 'desc_null_1'
             mock_is_b.side_effect = ['asc_null_filter_1', 'asc_null_filter_2']
             mock_is_c.side_effect = ['desc_null_3', 'desc_null_filter_3']
@@ -463,7 +481,7 @@ class TestPaginateQuery(test_base.BaseTestCase):
                                  sort_dirs=['asc-nullslast', 'desc-nullsfirst',
                                             'desc-nullsfirst'])
 
-            mock_isnot.assert_called_once_with(None)
+            mock_is_not.assert_called_once_with(None)
             mock_is_a.assert_called_once_with(None)
             mock_is_b.assert_has_calls([mock.call(None), mock.call(None)])
             mock_is_c.assert_has_calls([mock.call(None), mock.call(None)])
@@ -476,14 +494,14 @@ class TestPaginateQuery(test_base.BaseTestCase):
             mock.call('desc_null_3'),
             mock.call(self.model.project_id),
         ])
-        self.query.order_by.assert_has_calls = [
+        self.query.order_by.assert_has_calls([
             mock.call('asc_null_2'),
             mock.call('asc_1'),
             mock.call('desc_null_2'),
             mock.call('desc_1'),
             mock.call('desc_null_4'),
             mock.call('desc_4'),
-        ]
+        ])
         mock_or.assert_has_calls([
             mock.call(mock.ANY, 'asc_null_filter_2'),
             mock.call(mock.ANY, 'desc_null_filter_3'),
@@ -581,7 +599,7 @@ class TestGetUniqueKeys(test_base.BaseTestCase):
 
     def test_cache(self):
 
-        class CacheTable(object):
+        class CacheTable:
             info = {}
             constraints_called = 0
             indexes_called = 0
@@ -596,7 +614,7 @@ class TestGetUniqueKeys(test_base.BaseTestCase):
                 self.indexes_called += 1
                 return []
 
-        class CacheModel(object):
+        class CacheModel:
             pass
 
         table = CacheTable()
@@ -666,7 +684,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
     """Class for testing utils that are used in db migrations."""
 
     def setUp(self):
-        super(TestMigrationUtils, self).setUp()
+        super().setUp()
         self.meta = MetaData()
         self.conn = self.engine.connect()
 
@@ -782,173 +800,6 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         for value in soft_deleted_values:
             self.assertIn(value['id'], deleted_rows_ids)
 
-    def test_change_deleted_column_type_does_not_drop_index(self):
-        table_name = 'abc'
-
-        indexes = {
-            'idx_a_deleted': ['a', 'deleted'],
-            'idx_b_deleted': ['b', 'deleted'],
-            'idx_a': ['a']
-        }
-
-        index_instances = [Index(name, *columns)
-                           for name, columns in indexes.items()]
-
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('a', String(255)),
-                      Column('b', String(255)),
-                      Column('deleted', Boolean),
-                      *index_instances)
-        table.create(self.engine)
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name)
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name)
-
-        insp = sqlalchemy.inspect(self.engine)
-        real_indexes = insp.get_indexes(table_name)
-        self.assertEqual(3, len(real_indexes))
-        for index in real_indexes:
-            name = index['name']
-            self.assertIn(name, indexes)
-            self.assertEqual(set(indexes[name]),
-                             set(index['column_names']))
-
-    def test_change_deleted_column_type_to_id_type_integer(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type, Integer)
-
-    def test_change_deleted_column_type_to_id_type_string(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', String(255), primary_key=True),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type, String)
-
-    @db_test_base.backend_specific('sqlite')
-    def test_change_deleted_column_type_to_id_type_custom(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('foo', CustomType),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-
-        fooColumn = Column('foo', CustomType())
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name,
-                                                    foo=fooColumn)
-
-        table = utils.get_table(self.engine, table_name)
-
-        self.assertIsInstance(table.c.deleted.type, Integer)
-
-    def test_change_deleted_column_type_to_boolean(self):
-        expected_types = {'mysql': mysql.TINYINT}
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Integer))
-        table.create(self.engine)
-
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type,
-                              expected_types.get(self.engine.name, Boolean))
-
-    def test_change_deleted_column_type_to_boolean_with_fc(self):
-        expected_types = {'mysql': mysql.TINYINT}
-        table_name_1 = 'abc'
-        table_name_2 = 'bcd'
-
-        table_1 = Table(table_name_1, self.meta,
-                        Column('id', Integer, primary_key=True),
-                        Column('deleted', Integer))
-        table_1.create(self.engine)
-
-        table_2 = Table(table_name_2, self.meta,
-                        Column('id', Integer, primary_key=True),
-                        Column('foreign_id', Integer,
-                               ForeignKey('%s.id' % table_name_1)),
-                        Column('deleted', Integer))
-        table_2.create(self.engine)
-
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name_2)
-
-        table = utils.get_table(self.engine, table_name_2)
-        self.assertIsInstance(table.c.deleted.type,
-                              expected_types.get(self.engine.name, Boolean))
-
-    @db_test_base.backend_specific('sqlite')
-    def test_change_deleted_column_type_to_boolean_type_custom(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('foo', CustomType),
-                      Column('deleted', Integer))
-        table.create(self.engine)
-
-        fooColumn = Column('foo', CustomType())
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name,
-                                                    foo=fooColumn)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type, Boolean)
-
-    def test_detect_boolean_deleted_constraint_detection(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Boolean(create_constraint=True)))
-        ck = [
-            const for const in table.constraints if
-            isinstance(const, CheckConstraint)][0]
-
-        self.assertTrue(utils._is_deleted_column_constraint(ck))
-
-        self.assertFalse(
-            utils._is_deleted_column_constraint(
-                CheckConstraint("deleted > 5")
-            )
-        )
-
-    @db_test_base.backend_specific('sqlite')
-    def test_change_deleted_column_type_sqlite_drops_check_constraint(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-
-        utils._change_deleted_column_type_to_id_type_sqlite(self.engine,
-                                                            table_name)
-        table = Table(table_name, self.meta, autoload_with=self.engine)
-        # NOTE(I159): if the CHECK constraint has been dropped (expected
-        # behavior), any integer value can be inserted, otherwise only 1 or 0.
-        # NOTE(zzzeek): SQLAlchemy 1.2 Boolean type will disallow non 1/0
-        # value here, 1.1 also coerces to "1/0" so use raw SQL to test the
-        # constraint
-        with self.engine.connect() as conn, conn.begin():
-            conn.exec_driver_sql(
-                "INSERT INTO abc (deleted) VALUES (?)",
-                (10, ),
-            )
-
-            self.assertEqual(
-                10,
-                conn.scalar(sql.text("SELECT deleted FROM abc")),
-            )
-
     def test_get_foreign_key_constraint_name(self):
         table_1 = Table('table_name_1', self.meta,
                         Column('id', Integer, primary_key=True),
@@ -967,103 +818,6 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                                                     'foreign_id')
         self.assertEqual(fkc, 'table_name_2_fk1')
 
-    @db_test_base.backend_specific('mysql', 'postgresql')
-    def test_suspend_fk_constraints_for_col_alter(self):
-
-        a = Table(
-            'a', self.meta,
-            Column('id', Integer, primary_key=True)
-        )
-        b = Table(
-            'b', self.meta,
-            Column('key', Integer),
-            Column('archive_id', Integer),
-            Column('aid', ForeignKey('a.id')),
-            PrimaryKeyConstraint("key", "archive_id")
-        )
-        c = Table(
-            'c', self.meta,
-            Column('id', Integer, primary_key=True),
-            Column('aid', ForeignKey('a.id')),
-            Column('key', Integer),
-            Column('archive_id', Integer),
-            ForeignKeyConstraint(
-                ['key', 'archive_id'], ['b.key', 'b.archive_id'],
-                name="some_composite_fk")
-        )
-        self.meta.create_all(self.engine, tables=[a, b, c])
-
-        def get_fk_entries():
-            inspector = sqlalchemy.inspect(self.engine)
-            return sorted(
-                inspector.get_foreign_keys('b') +
-                inspector.get_foreign_keys('c'),
-                key=lambda fk: fk['referred_table']
-            )
-
-        def normalize_fk_entries(fks):
-            return [{
-                    'name': fk['name'],
-                    'referred_columns': fk['referred_columns'],
-                    'referred_table': fk['referred_table'],
-                    } for fk in fks]
-
-        existing_foreign_keys = get_fk_entries()
-        self.assertEqual(
-            [{'name': mock.ANY,
-              'referred_columns': ['id'], 'referred_table': 'a'},
-                {'name': mock.ANY,
-                 'referred_columns': ['id'], 'referred_table': 'a'},
-                {'name': 'some_composite_fk',
-                 'referred_columns': ['key', 'archive_id'],
-                 'referred_table': 'b'}],
-            normalize_fk_entries(existing_foreign_keys)
-        )
-
-        with mock.patch("oslo_db.sqlalchemy.ndb.ndb_status",
-                        mock.Mock(return_value=True)):
-            with utils.suspend_fk_constraints_for_col_alter(
-                    self.engine, 'a', 'id', referents=['b', 'c']):
-                no_a_foreign_keys = get_fk_entries()
-                self.assertEqual(
-                    [{'name': 'some_composite_fk',
-                      'referred_columns': ['key', 'archive_id'],
-                      'referred_table': 'b'}],
-                    normalize_fk_entries(no_a_foreign_keys)
-                )
-
-        self.assertEqual(existing_foreign_keys, get_fk_entries())
-
-        with mock.patch("oslo_db.sqlalchemy.ndb.ndb_status",
-                        mock.Mock(return_value=True)):
-            with utils.suspend_fk_constraints_for_col_alter(
-                    self.engine, 'b', 'archive_id', referents=['c']):
-                self.assertEqual(
-                    [{'name': mock.ANY,
-                      'referred_columns': ['id'], 'referred_table': 'a'},
-                        {'name': mock.ANY,
-                         'referred_columns': ['id'], 'referred_table': 'a'}],
-                    normalize_fk_entries(get_fk_entries())
-                )
-
-        self.assertEqual(existing_foreign_keys, get_fk_entries())
-
-        with utils.suspend_fk_constraints_for_col_alter(
-                self.engine, 'a', 'id', referents=['b', 'c']):
-            self.assertEqual(existing_foreign_keys, get_fk_entries())
-
-        if self.engine.name == 'mysql':
-            self.engine.dialect._oslodb_enable_ndb_support = True
-
-            self.addCleanup(
-                setattr, self.engine.dialect, "_oslodb_enable_ndb_support",
-                False
-            )
-
-            with utils.suspend_fk_constraints_for_col_alter(
-                    self.engine, 'a', 'id', referents=['b', 'c']):
-                self.assertEqual(no_a_foreign_keys, get_fk_entries())
-
 
 class PostgresqlTestMigrations(TestMigrationUtils,
                                db_test_base._PostgreSQLOpportunisticTestCase):
@@ -1082,14 +836,14 @@ class MySQLTestMigrations(TestMigrationUtils,
 class TestConnectionUtils(test_base.BaseTestCase):
 
     def setUp(self):
-        super(TestConnectionUtils, self).setUp()
+        super().setUp()
 
-        self.full_credentials = {'backend': 'postgresql',
+        self.full_credentials = {'backend': 'postgresql+psycopg2',
                                  'database': 'test',
                                  'user': 'dude',
                                  'passwd': 'pass'}
 
-        self.connect_string = 'postgresql://dude:pass@localhost/test'
+        self.connect_string = 'postgresql+psycopg2://dude:pass@localhost/test'
 
         # NOTE(rpodolyaka): mock the dialect parts, so that we don't depend
         # on psycopg2 (or any other DBAPI implementation) in these tests
@@ -1097,8 +851,20 @@ class TestConnectionUtils(test_base.BaseTestCase):
         @classmethod
         def fake_dbapi(cls):
             return mock.MagicMock()
-        patch_dbapi = mock.patch.object(psycopg2.PGDialect_psycopg2, 'dbapi',
-                                        new=fake_dbapi)
+
+        class OurDialect(psycopg2.PGDialect_psycopg2):
+            def dbapi(self):
+                return fake_dbapi
+
+            def import_dbapi(self):
+                return fake_dbapi
+
+        patch_dbapi = mock.patch.object(
+            psycopg2,
+            "PGDialect_psycopg2",
+            new=OurDialect,
+        )
+
         patch_dbapi.start()
         self.addCleanup(patch_dbapi.stop)
 
@@ -1117,7 +883,7 @@ class TestConnectionUtils(test_base.BaseTestCase):
                 self.connect_string)
 
             self.assertIsInstance(eng, sqlalchemy.engine.base.Engine)
-            self.assertEqual(self.connect_string, str(eng.url))
+            self.assertEqual(utils.make_url(self.connect_string), eng.url)
 
             mock_connect.assert_called_once()
             fake_connection.close.assert_called_once()
@@ -1134,10 +900,10 @@ class TestConnectionUtils(test_base.BaseTestCase):
                 provision.Backend._ensure_backend_available,
                 self.connect_string)
             self.assertEqual(
-                "Backend 'postgresql' is unavailable: "
+                "Backend 'postgresql+psycopg2' is unavailable: "
                 "Could not connect", str(exc))
             self.assertEqual(
-                "The postgresql backend is unavailable: %s" % err,
+                "The postgresql+psycopg2 backend is unavailable: %s" % err,
                 log.output.strip())
 
     def test_ensure_backend_available_no_dbapi_raises(self):
@@ -1152,13 +918,13 @@ class TestConnectionUtils(test_base.BaseTestCase):
                 self.connect_string)
 
             mock_create.assert_called_once_with(
-                sa_url.make_url(self.connect_string))
+                utils.make_url(self.connect_string))
 
             self.assertEqual(
-                "Backend 'postgresql' is unavailable: "
+                "Backend 'postgresql+psycopg2' is unavailable: "
                 "No DBAPI installed", str(exc))
             self.assertEqual(
-                "The postgresql backend is unavailable: Can't import "
+                "The postgresql+psycopg2 backend is unavailable: Can't import "
                 "DBAPI module foobar", log.output.strip())
 
     def test_get_db_connection_info(self):
@@ -1188,7 +954,7 @@ class MyModelSoftDeleted(declarative_base(), models.ModelBase,
 class TestModelQuery(test_base.BaseTestCase):
 
     def setUp(self):
-        super(TestModelQuery, self).setUp()
+        super().setUp()
 
         self.session = mock.MagicMock()
         self.session.query.return_value = self.session.query
@@ -1250,10 +1016,13 @@ class TestModelQuery(test_base.BaseTestCase):
             MyModelSoftDeletedProjectId,
             session=self.session, project_id=(10, None))
 
-        self.assertEqual(
+        self.assertRegex(
+            str(
+                mock_query.filter.call_args[0][0].
+                compile(compile_kwargs={"render_postcompile": True})
+            ),
             'soft_deleted_project_id_test_model.project_id'
-            ' IN (:project_id_1, NULL)',
-            str(mock_query.filter.call_args[0][0])
+            r' IN \(:project_id.+, (?::project_id.+|NULL)\)',
         )
 
     def test_model_query_common(self):
@@ -1263,7 +1032,7 @@ class TestModelQuery(test_base.BaseTestCase):
 
 class TestUtils(db_test_base._DbTestCase):
     def setUp(self):
-        super(TestUtils, self).setUp()
+        super().setUp()
         meta = MetaData()
         self.test_table = Table(
             'test_table',
@@ -1507,10 +1276,9 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
             )
         )
 
-        mysqldb_url = sqlalchemy.engine.url.make_url("mysql+mysqldb://")
-        mysqlconnector_url = sqlalchemy.engine.url.make_url(
-            "mysql+mysqlconnector://")
-        sqlite_url = sqlalchemy.engine.url.make_url("sqlite://")
+        mysqldb_url = utils.make_url("mysql+mysqldb://")
+        mysqlconnector_url = utils.make_url("mysql+mysqlconnector://")
+        sqlite_url = utils.make_url("sqlite://")
 
         dispatcher(mysqldb_url, 1)
         dispatcher(mysqlconnector_url, 2)
@@ -1546,8 +1314,7 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
         )
 
     def test_url_pymysql(self):
-        url = sqlalchemy.engine.url.make_url(
-            "mysql+pymysql://scott:tiger@localhost/test")
+        url = utils.make_url("mysql+pymysql://scott:tiger@localhost/test")
         dispatcher, callable_fn = self._single_fixture()
 
         dispatcher(url, 15)
@@ -1557,8 +1324,7 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
         )
 
     def test_url_mysql_generic(self):
-        url = sqlalchemy.engine.url.make_url(
-            "mysql://scott:tiger@localhost/test")
+        url = utils.make_url("mysql://scott:tiger@localhost/test")
         dispatcher, callable_fn = self._single_fixture()
 
         dispatcher(url, 15)
